@@ -14,7 +14,7 @@ static void numer_hessian(_subplex_objective_function *f, const double *x, const
 
 SEXP call_subplex(SEXP x, SEXP f, SEXP tol, SEXP maxnfe, SEXP scale, SEXP hessian, SEXP rho, SEXP args);
 
-void F77_NAME(subplx) (_subplex_objective_function *f, int *n, double *tol, int *maxnfe, int *mode,
+void F77_NAME(subplx) (_subplex_objective_function *f, int *n, double *tol, int *maxnfe,
 		       double *scale, double *x, double *fx, int *nfe, double *work, int *iwork,
 		       int *iflag);
 
@@ -27,7 +27,7 @@ SEXP call_subplex (SEXP x, SEXP f, SEXP tol, SEXP maxnfe, SEXP scale, SEXP hessi
 {
   int nprotect = 0;
   double *work = 0, *scalp, *xp, *Xp, eps, *hstep;
-  int n, *iwork = 0, mode = 0;
+  int n, *iwork = 0;
   int k, nscal;
   int hess_reqd;
   _subplex_objective_function *objfn = default_subplex_objective;
@@ -39,6 +39,9 @@ SEXP call_subplex (SEXP x, SEXP f, SEXP tol, SEXP maxnfe, SEXP scale, SEXP hessi
 
   n = LENGTH(x);
   PROTECT(x = AS_NUMERIC(x)); nprotect++;
+  if (n < 1) {
+    errorcall(R_NilValue,"'par' must be a non-empty vector");
+  }
 
   // check the convergence tolerance, tol
   PROTECT(tol = AS_NUMERIC(tol)); nprotect++;
@@ -89,30 +92,29 @@ SEXP call_subplex (SEXP x, SEXP f, SEXP tol, SEXP maxnfe, SEXP scale, SEXP hessi
   xp = REAL(x); Xp = REAL(X);
   for (k = 0; k < n; k++) Xp[k] = xp[k]; // copy in the initial guess vector
 
-  F77_CALL(subplx)(objfn,&n,REAL(tol),INTEGER(maxnfe),&mode,scalp,Xp,REAL(val),INTEGER(counts),
+  F77_CALL(subplx)(objfn,&n,REAL(tol),INTEGER(maxnfe),scalp,Xp,REAL(val),INTEGER(counts),
 		   work,iwork,INTEGER(conv));
 
   Free(iwork);
   Free(work);
 
-  if (INTEGER_VALUE(conv) == -2) {
-    UNPROTECT(nprotect);
-    errorcall(R_NilValue,"illegal input in subplex");
-  }
-
-  if (INTEGER_VALUE(conv) != 0) {
-    PROTECT(message = NEW_CHARACTER(1)); nprotect++;
-    switch (INTEGER_VALUE(conv)) {
-    case -1:
-      SET_STRING_ELT(message,0,mkChar("number of function evaluations exceeds 'maxit'"));
-      break;
-    case 1:
-      SET_STRING_ELT(message,0,mkChar("limit of machine precision reached"));
-      break;
-    case 2:
-      SET_STRING_ELT(message,0,mkChar("fstop reached"));
-      break;
-    }
+  PROTECT(message = NEW_CHARACTER(1)); nprotect++;
+  switch (INTEGER_VALUE(conv)) {
+  case -1:
+    SET_STRING_ELT(message,0,mkChar("number of function evaluations exceeds 'maxit'"));
+    break;
+  case 0:
+    SET_STRING_ELT(message,0,mkChar("success! tolerance satisfied"));
+    break;
+  case 1:
+    SET_STRING_ELT(message,0,mkChar("limit of machine precision reached"));
+    break;
+  case -2:
+    errorcall(R_NilValue,"'parscale' is too small relative to 'par'");
+    break;
+  case 2: default:
+    errorcall(R_NilValue,"impossible error in subplex"); // # nocov
+    break;
   }
 
   if (hess_reqd) {	     // compute the Hessian matrix if required
